{ pkgs, nix-config, pkgs-local, lib, ... }:

{

  imports = with nix-config.homeModules; [
    niri
    waybar
    swaync
    mpv
    hyprlock
    hypridle
    sway-launcher-desktop
    browsers
  ];

  home.packages = with pkgs; [

    filen-desktop
    filen-cli

    szyszka

    appimage-run
    libappimage
    transmission_4-gtk
    wl-clipboard
    clipse
    wayland-utils
    libheif.out
    rpi-imager
    freecad
    flatpak
    prusa-slicer
    via
    vial
    pdfarranger
    tdf
    pdfchain
    pdftk
    zathura
    gpu-viewer
    foliate
    wl-mirror
    soundconverter
    wmctrl

    scribus
    gimp3

    # godot_4
    # gdtoolkit_4

    epsonscan2
    # sane-airscan
    xsane

    bitwarden-cli
    bitwarden-desktop
    tailscale
    trayscale
    font-manager

    # papers
    newsflash

    stirling-pdf
    ripdrag

    polychromatic

    emojify
    smile

    impression
    zoom-us
    nyxt

    obsidian
    vlc
    discord
    slack
    signal-desktop-bin
    libreoffice
    hyphenDicts.en_US
    plex-mpv-shim
    plexamp

    switcheroo

    blender
    davinci-resolve-studio
    processing
    zotero
    # pkgs-local.zotero-latest
    fractal
    handbrake
    gmic
    krita
    krita-plugin-gmic
    rawtherapee
    inkscape

    (kicad.override {
      addons = with pkgs.kicadAddons; [ kikit kikit-library ];
    })

    turbocase
    openscad-unstable
    openscad-lsp

    picard
    plugdata
    pavucontrol
    qpwgraph
    clapper
    ardour
    halloy
    paleta
    wayback
    protonplus
    fstl

    eog

    wl-color-picker

    # screen recording and streaming
    kooha
    obs-studio
    obs-studio-plugins.wlrobs
    obs-studio-plugins.obs-gstreamer

    wineWowPackages.yabridge
    winetricks

    virt-manager

    gnome-photos
    gnome-tweaks
    nautilus
    nautilus-open-any-terminal
    turtle
    gnome-online-accounts
    gnome-online-accounts-gtk
    gnome-calculator
    gnome-calendar
    evolution
    wordbook

    protonup
    mangohud
    dualsensectl.out

  ];

  home.pointerCursor = {
    enable = true;
    name = pkgs.rice.cursor.name;
    package = pkgs.rice.cursor.package;
    size = pkgs.rice.cursor.size;
    gtk.enable = true;
    x11.enable = true;
    dotIcons.enable = true;
    hyprcursor.enable = true;
  };

  gtk = {
    enable = true;
    cursorTheme = {
      name = pkgs.rice.cursor.name;
      package = pkgs.rice.cursor.package;
      size = pkgs.rice.cursor.size;
    };
    theme = {
      name = "Colloid";
      package = pkgs.colloid-gtk-theme.override {
        colorVariants = [ "dark" ];
        tweaks = [ "normal" "nord" ];
        themeVariants = [ "grey" ];
      };
    };
    iconTheme = {
      name = "Colloid";
      package = pkgs.colloid-icon-theme;
    };
  };

  qt = {
    enable = true;
    platformTheme = {
      name = "gtk";
    };
    style = {
      package = pkgs.adwaita-qt;
      name = "adwaita-dark";
    };
  };

  dconf.settings = {
    "org/gnome/desktop/interface" = {
      color-scheme = "prefer-dark";
      gtk-theme = lib.mkForce "Colloid-Grey-Dark-Nord";
      clock-format = "12h";
    };
  };

  fonts = {
    fontconfig = {
      enable = true;
    };
  };

  services = {
    flatpak = {
      enable = true;
      packages = [
        "com.github.tchx84.Flatseal"
        "com.valvesoftware.SteamLink"
      ];
      overrides = {
        global = {
          Context.filesystems = [ "/nix/store:ro" ];
        };
      };
    };
    swayosd = {
      enable = true;
    };
    udiskie = {
      enable = true;
      automount = true;
      tray = "always";
      notify = false;
    };
    wpaperd = {
      enable = true;
      settings = {
        default = {
          mode = "fit";
        };
        any = {
          path = "/home/emenel/.local/wallpapers/crt1.jpg";
        };
      };
    };
  };

  # xdg.configFile."wpaperd/config.toml".source = ../../homes/emenel/dotfiles/dot_config/wpaperd/config.toml;
  home.file.".local/wallpapers".source = ../../assets/wallpapers;

  # xdg.mime = {
  #   enable = true;
  # };

  # xdg.mimeApps = {
  #   enable = true;
  #   defaultApplications = {
  #     "application/pdf" = [ "zen-twilight.desktop" ];
  #   };
  #   associations = {
  #     added = {
  #       "application/pdf" = [ "zen-twilight.desktop" ];
  #     };
  #     removed = {
  #       "application/pdf" = [ "chromium-browser.desktop" ];
  #     };
  #   };
  # };

  # xdg.portal = {
  #   enable = true;
  #   configPackages = [ pkgs.niri-unstable ];
  #   extraPortals = with pkgs; [
  #     xdg-desktop-portal-gnome
  #     xdg-desktop-portal-gtk
  #     xdg-desktop-portal
  #     xdg-desktop-portal-wlr
  #     gnome-keyring
  #     xdg-desktop-portal-termfilechooser
  #   ];
  #   config = {
  #     common = {
  #       default = [ "gtk" ];
  #       # "org.freedesktop.impl.portal.FileChooser" = "termfilechooser";
  #     };
  #   };
  # };

  # home.sessionVariables.TERMCMD = "wezterm --class=file_chooser";

  xdg.desktopEntries = {
    rmpc = {
      name = "rmpc (music player)";
      exec = "/home/emenel/.local/bin/wezapp rmpc";
    };
    isd = {
      name = "isd (interactive systemd)";
      exec = "/home/emenel/.local/bin/wezapp isd";
      categories = [ "System" ];
    };
    mirror-laptop = {
      name = "mirror laptop";
      exec = "/home/emenel/.local/bin/mirror-laptop";
      categories = [ "System" ];
    };
    btop = {
      name = "btop++";
      exec = "/home/emenel/.local/bin/wezapp btop";
      categories = [ "System" ];
    };
    steam-offload = {
      name = "Steam (nvidia-offload)";
      exec = "nvidia-offload ${pkgs.steam}/bin/steam";
    };
    bluetui = {
      name = "bluetui (bluetooth manager)";
      exec = "/home/emenel/.local/bin/wezapp bluetui";
    };
    color-picker-clip = {
      name = "wl color picker (clipboard)";
      exec = "${pkgs.wl-color-picker}/bin/wl-color-picker clipboard";
    };
    color-picker = {
      name = "wl color picker";
      exec = "${pkgs.wl-color-picker}/bin/wl-color-picker";
    };
  };

  xdg.configFile."halloy/config.toml".source = ../../homes/emenel/dotfiles/dot_config/halloy/config.toml;
  # xdg.configFile."nyxt/config.lisp".source = ../../homes/emenel/dotfiles/dot_config/nyxt/config.lisp;
}
